##  Testing the Survey
After completing your survey design, you can test it by clicking the Test Survey button. Add an email address and send it out to observe how the survey appears to your recipients, ensuring that everything looks as intended before running the survey. You can test the complete user journey of a survey recipient, starting from the survey invite showing up in your inbox, viewing the survey form, filling out the form, and submitting the survey. During a test run, only one fact sheet is displayed, as the survey response form remains consistent for all fact sheets. If everything looks as intended, hit Go Live to execute the survey.
YesNo
Send
